@@ -11,7 +11,7 @@ _PROJECT_ROOT = "."
 _SOURCE_ROOT = os.path.join(_PROJECT_ROOT, "src")
 _PACKAGE_ROOT = os.path.join(_SOURCE_ROOT, "lightning_app")
 _PATH_REQUIREMENTS = os.path.join("requirements", "app")
-_FREEZE_REQUIREMENTS = bool(int(os.environ.get("FREEZE_REQUIREMENTS", 0)))
+_FREEZE_REQUIREMENTS = os.environ.get("FREEZE_REQUIREMENTS", "0").lower() in ("1", "true")
 
 
 def _load_py_module(name: str, location: str) -> ModuleType:
@@ -74,7 +74,7 @@ def _setup_args() -> Dict[str, Any]:
         include_package_data=True,
         zip_safe=False,
         keywords=["deep learning", "pytorch", "AI"],
-        python_requires=">=3.7",
+        python_requires=">=3.8",
         entry_points={
             "console_scripts": [
                 "lightning = lightning_app.cli.lightning_cli:main",
@@ -106,7 +106,6 @@ def _setup_args() -> Dict[str, Any]:
             # Specify the Python versions you support here. In particular, ensure
             # that you indicate whether you support Python 2, Python 3 or both.
             "Programming Language :: Python :: 3",
-            "Programming Language :: Python :: 3.7",
             "Programming Language :: Python :: 3.8",
             "Programming Language :: Python :: 3.9",
             "Programming Language :: Python :: 3.10",
