@@ -1,4 +1,4 @@
-import lightning as L
+import lightning_app as L
 
 
 class ComponentA(L.LightningFlow):
