@@ -1,10 +1,24 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import sys
 from typing import Dict, Optional
 
 import requests
 
-from lightning_app.cli.commands.connection import (
+from lightning_app.cli.connect.app import (
     _clean_lightning_connection,
     _install_missing_requirements,
     _resolve_command_path,
