@@ -1,6 +1,6 @@
 from placeholdername import TemplateComponent
 
-import lightning as L
+import lightning_app as L
 
 
 class LitApp(L.LightningFlow):
