@@ -16,7 +16,7 @@ import os
 import shutil
 import sys
 from pathlib import Path
-from typing import Tuple, Union
+from typing import Optional, Tuple, Union
 
 import arrow
 import click
@@ -46,7 +46,7 @@ from lightning_app.cli.connect.app import (
     disconnect_app,
 )
 from lightning_app.cli.connect.data import connect_data
-from lightning_app.cli.connect.node import connect_node, disconnect_node
+from lightning_app.cli.connect.maverick import connect_maverick, disconnect_maverick
 from lightning_app.cli.lightning_cli_create import create
 from lightning_app.cli.lightning_cli_delete import delete
 from lightning_app.cli.lightning_cli_list import get_list
@@ -148,8 +148,8 @@ def disconnect() -> None:
 
 connect.command("app")(connect_app)
 disconnect.command("app")(disconnect_app)
-connect.command("node", hidden=True)(connect_node)
-disconnect.command("node", hidden=True)(disconnect_node)
+connect.command("maverick", hidden=True)(connect_maverick)
+disconnect.command("maverick", hidden=True)(disconnect_maverick)
 connect.command("data", hidden=True)(connect_data)
 _main.command(hidden=True)(ls)
 _main.command(hidden=True)(cd)
@@ -426,8 +426,8 @@ def run_app(
     )
 
 
-if RequirementCache("lightning-fabric>=1.9.0") or RequirementCache("lightning>=1.9.0"):
-    # note it is automatically replaced to `from lightning.fabric.cli` when building monolithic/mirror package
+if RequirementCache("lightning_fabric>=1.9.0") or RequirementCache("lightning>=1.9.0"):
+    # note it is automatically replaced to `from lightning_fabric.cli` when building monolithic/mirror package
     from lightning_fabric.cli import _run_model
 
     run.add_command(_run_model)
@@ -474,7 +474,7 @@ _main.add_command(cmd_install.install)
     default=None,
     help="Specify which component to SSH into",
 )
-def ssh(app_name: str = None, component_name: str = None) -> None:
+def ssh(app_name: Optional[str] = None, component_name: Optional[str] = None) -> None:
     """SSH into a Lightning App."""
 
     app_manager = _AppManager()
