@@ -2,8 +2,8 @@
 
 from pathlib import Path
 
-import lightning as L
-from lightning.app import frontend
+import lightning_app as L
+from lightning_app import frontend
 
 
 class YourComponent(L.LightningFlow):
