@@ -37,7 +37,7 @@ class MultiNode(LightningFlow):
 
             import torch
 
-            import lightning as L
+            import lightning_app as L
             from lightning.components import MultiNode
 
             class AnyDistributedComponent(L.LightningWork):
