@@ -12,9 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Any, Callable, Type
-
-from typing_extensions import Protocol, runtime_checkable
+from typing import Any, Callable, Protocol, runtime_checkable, Type
 
 from lightning_app.components.multi_node.base import MultiNode
 from lightning_app.core.queues import MultiProcessQueue
@@ -57,7 +55,7 @@ class _PyTorchSpawnRunExecutor(WorkRunExecutor):
             )
 
     @staticmethod
-    def dispatch_run(local_rank, cls, work, delta_queue, *args, **kwargs):
+    def dispatch_run(local_rank, cls, work, delta_queue, *args: Any, **kwargs: Any):
         if local_rank == 0:
             if isinstance(delta_queue, dict):
                 delta_queue = cls.process_queue(delta_queue)
