@@ -47,7 +47,7 @@ logger = Logger(__name__)
 class _TrackableFastAPI(FastAPI):
     """A FastAPI subclass that tracks the request metadata."""
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         super().__init__(*args, **kwargs)
         self.global_request_count = 0
         self.num_current_requests = 0
@@ -499,7 +499,7 @@ class AutoScaler(LightningFlow):
 
     .. testcode::
 
-        import lightning as L
+        import lightning_app as L
 
         # Example 1: Auto-scaling serve component out-of-the-box
         app = L.LightningApp(
