@@ -31,12 +31,12 @@ class ServeGradio(LightningWork, abc.ABC):
 
     In the example below, the ``ServeGradio`` is subclassed to deploy ``AnimeGANv2``.
 
-    .. literalinclude:: ../../../examples/app_components/serve/gradio/app.py
+    .. literalinclude:: ../../../../examples/app/components/serve/gradio/app.py
         :language: python
 
     The result would be the following:
 
-    .. image:: https://pl-flash-data.s3.amazonaws.com/assets_lightning/anime_gan.gif
+    .. image:: https://pl-public-data.s3.amazonaws.com/assets_lightning/anime_gan.gif
         :alt: Animation showing how to AnimeGANv2 UI would looks like.
     """
 
@@ -49,7 +49,7 @@ class ServeGradio(LightningWork, abc.ABC):
 
     _start_method = "spawn"
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         requires("gradio")(super().__init__(*args, **kwargs))
         assert self.inputs
         assert self.outputs
@@ -62,7 +62,7 @@ class ServeGradio(LightningWork, abc.ABC):
         return self._model
 
     @abc.abstractmethod
-    def predict(self, *args, **kwargs):
+    def predict(self, *args: Any, **kwargs: Any):
         """Override with your logic to make a prediction."""
 
     @abc.abstractmethod
@@ -72,7 +72,7 @@ class ServeGradio(LightningWork, abc.ABC):
         The model would be accessible under self.model
         """
 
-    def run(self, *args, **kwargs):
+    def run(self, *args: Any, **kwargs: Any):
         if self._model is None:
             self._model = self.build_model()
         fn = partial(self.predict, *args, **kwargs)
