@@ -164,7 +164,7 @@ class PythonServer(LightningWork, abc.ABC):
         self,
         input_type: type = _DefaultInputData,
         output_type: type = _DefaultOutputData,
-        **kwargs,
+        **kwargs: Any,
     ):
         """The PythonServer Class enables to easily get your machine learning server up and running.
 
@@ -222,7 +222,7 @@ class PythonServer(LightningWork, abc.ABC):
 
         self.ready = False
 
-    def setup(self, *args, **kwargs) -> None:
+    def setup(self, *args: Any, **kwargs: Any) -> None:
         """This method is called before the server starts. Override this if you need to download the model or
         initialize the weights, setting up pipelines etc.
 
