@@ -45,8 +45,8 @@ class JustPyFrontend(Frontend):
         .. code-block:: python
 
             from typing import Callable
-            from lightning import LightningApp, LightningFlow
-            from lightning.app.frontend import JustPyFrontend
+            from lightning_app import LightningApp, LightningFlow
+            from lightning_app.frontend import JustPyFrontend
 
 
             class Flow(LightningFlow):
