@@ -1,10 +1,23 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """The watch_app_state function enables us to trigger a callback function when ever the app state changes."""
 # Todo: Refactor with Streamlit
 # Note: It would be nice one day to just watch changes within the Flow scope instead of whole app
 from __future__ import annotations
 
 import asyncio
-import logging
 import os
 from threading import Thread
 from typing import Callable
@@ -12,8 +25,9 @@ from typing import Callable
 import websockets
 
 from lightning_app.core.constants import APP_SERVER_PORT
+from lightning_app.utilities.app_helpers import Logger
 
-_logger = logging.getLogger(__name__)
+_logger = Logger(__name__)
 
 _CALLBACKS = []
 _THREAD: Thread = None
@@ -68,7 +82,7 @@ def _start_websocket():
         _logger.debug("thread started")
 
 
-def watch_app_state(callback: Callable):
+def _watch_app_state(callback: Callable):
     """Start the process that serves the UI at the given hostname and port number.
 
     Arguments:
