@@ -74,7 +74,7 @@ class PanelFrontend(Frontend):
 
     .. code-block:: python
 
-        import lightning as L
+        import lightning_app as L
         from lightning_app.frontend.panel import PanelFrontend
 
 
