@@ -30,6 +30,7 @@ from typing import Any, Callable, Dict, Generator, List, Optional, Type
 import requests
 from lightning_cloud.openapi import V1LightningappInstanceState
 from lightning_cloud.openapi.rest import ApiException
+from lightning_utilities.core.imports import package_available
 from requests import Session
 from rich import print
 from rich.color import ANSI_COLOR_NAMES
@@ -98,7 +99,7 @@ def _print_logs(app_id: str):
 
 
 class LightningTestApp(LightningApp):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         super().__init__(*args, **kwargs)
         self.counter = 0
 
@@ -106,11 +107,11 @@ class LightningTestApp(LightningApp):
     def _configure_session() -> Session:
         return _configure_session()
 
-    def make_request(self, fn, *args, **kwargs):
+    def make_request(self, fn, *args: Any, **kwargs: Any):
         loop = asyncio.new_event_loop()
         loop.run_until_complete(self._make_request(fn, *args, **kwargs))
 
-    async def _make_request(self, fn: Callable, *args, **kwargs):
+    async def _make_request(self, fn: Callable, *args: Any, **kwargs: Any):
         from lightning_app.utilities.state import AppState
 
         state = AppState()
@@ -144,18 +145,14 @@ class LightningTestApp(LightningApp):
 
 
 @requires("click")
-def application_testing(
-    lightning_app_cls: Type[LightningTestApp] = LightningTestApp, command_line: List[str] = []
-) -> Any:
+def application_testing(lit_app_cls: Type[LightningTestApp] = LightningTestApp, command_line: List[str] = []) -> Any:
     from unittest import mock
 
     from click.testing import CliRunner
 
-    patch1 = mock.patch("lightning_app.LightningApp", lightning_app_cls)
+    patch1 = mock.patch("lightning_app.LightningApp", lit_app_cls)
     # we need to patch both only with the mirror package
-    patch2 = (
-        mock.patch("lightning.LightningApp", lightning_app_cls) if "lightning.app" in sys.modules else nullcontext()
-    )
+    patch2 = mock.patch("lightning.LightningApp", lit_app_cls) if package_available("lightning") else nullcontext()
     with patch1, patch2:
         original = sys.argv
         sys.argv = command_line
@@ -178,7 +175,7 @@ class _SingleWorkFlow(LightningFlow):
         self.work.run(*self.args, **self.kwargs)
 
 
-def run_work_isolated(work, *args, start_server: bool = False, **kwargs):
+def run_work_isolated(work, *args: Any, start_server: bool = False, **kwargs: Any):
     """This function is used to run a work a single time with multiprocessing runtime."""
     MultiProcessRuntime(
         LightningApp(_SingleWorkFlow(work, args, kwargs), log_level="debug"),
@@ -450,7 +447,7 @@ def run_app_in_cloud(
             Popen("lightning disconnect", shell=True).wait()
 
 
-def wait_for(page, callback: Callable, *args, **kwargs) -> Any:
+def wait_for(page, callback: Callable, *args: Any, **kwargs: Any) -> Any:
     import playwright
 
     while True:
