@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import os
+from typing import Optional
 
 from lightning_cloud.openapi import V1Membership
 
@@ -22,10 +23,11 @@ from lightning_app.utilities.enum import AppStage
 from lightning_app.utilities.network import LightningClient
 
 
-def _get_project(
-    client: LightningClient, project_id: str = LIGHTNING_CLOUD_PROJECT_ID, verbose: bool = True
-) -> V1Membership:
+def _get_project(client: LightningClient, project_id: Optional[str] = None, verbose: bool = True) -> V1Membership:
     """Get a project membership for the user from the backend."""
+    if project_id is None:
+        project_id = LIGHTNING_CLOUD_PROJECT_ID
+
     projects = client.projects_service_list_memberships()
     if project_id is not None:
         for membership in projects.memberships:
