@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import ast
 import socket
 import time
 from functools import wraps
@@ -22,7 +21,6 @@ from urllib.parse import urljoin
 import lightning_cloud
 import requests
 import urllib3
-from fastapi import HTTPException
 from lightning_cloud.rest_client import create_swagger_client, GridRestClient
 from requests import Session
 from requests.adapters import HTTPAdapter
@@ -139,8 +137,6 @@ def _retry_wrapper(self, func: Callable) -> Callable:
             try:
                 return func(self, *args, **kwargs)
             except lightning_cloud.openapi.rest.ApiException as e:
-                if e.status == 500:
-                    raise HTTPException(status_code=500, detail=ast.literal_eval(e.body.decode("utf-8"))["message"])
                 # retry if the control plane fails with all errors except 4xx but not 408 - (Request Timeout)
                 if e.status == 408 or e.status == 409 or not str(e.status).startswith("4"):
                     consecutive_errors += 1
@@ -185,11 +181,11 @@ class LightningClient(GridRestClient):
 
 
 class CustomRetryAdapter(HTTPAdapter):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         self.timeout = kwargs.pop("timeout", _DEFAULT_REQUEST_TIMEOUT)
         super().__init__(*args, **kwargs)
 
-    def send(self, request, **kwargs):
+    def send(self, request, **kwargs: Any):
         kwargs["timeout"] = kwargs.get("timeout", self.timeout)
         return super().send(request, **kwargs)
 
@@ -212,7 +208,7 @@ def _http_method_logger_wrapper(func: Callable) -> Callable:
     return wrapped
 
 
-def _response(r, *args, **kwargs):
+def _response(r, *args: Any, **kwargs: Any):
     return r.raise_for_status()
 
 
@@ -267,7 +263,7 @@ class HTTPClient:
         url = urljoin(self.base_url, path)
         return self.session.delete(url)
 
-    def log_function(self, message: str, *args, **kwargs):
+    def log_function(self, message: str, *args, **kwargs: Any):
         """This function is used to log the messages in the client, it can be overridden by caller to customise the
         logging logic.
 
